]> git.sesse.net Git - nageru/blobdiff - mixer.h
Set dts for audio; evidently needed to unconfuse players.
[nageru] / mixer.h
diff --git a/mixer.h b/mixer.h
index 594cb041ee1ece399abcb581aaf433677e81f7ab..9b631e4766071d35e6f0d215cd3f4442f46cdf2e 100644 (file)
--- a/mixer.h
+++ b/mixer.h
@@ -15,6 +15,7 @@
 #include "ref_counted_frame.h"
 #include "ref_counted_gl_sync.h"
 #include "theme.h"
+#include "resampler.h"
 
 #define NUM_CARDS 2
 
@@ -33,12 +34,15 @@ public:
        void quit();
 
        void transition_clicked(int transition_num);
+       void channel_clicked(int preview_num);
 
        enum Output {
                OUTPUT_LIVE = 0,
                OUTPUT_PREVIEW,
                OUTPUT_INPUT0,
                OUTPUT_INPUT1,
+               OUTPUT_INPUT2,
+               OUTPUT_INPUT3,
                NUM_OUTPUTS
        };
 
@@ -74,6 +78,11 @@ public:
                output_channel[output].set_frame_ready_callback(callback);
        }
 
+       std::vector<std::string> get_transition_names()
+       {
+               return theme->get_transition_names(frame / 60.0);
+       }
+
 private:
        void bm_frame(int card_index, uint16_t timecode,
                FrameAllocator::Frame video_frame, size_t video_offset, uint16_t video_format,
@@ -104,10 +113,12 @@ private:
                QSurface *surface;
                QOpenGLContext *context;
 
-               bool new_data_ready = false;  // Whether new_frame contains anything.
+               bool new_data_ready = false;  // Whether new_frame and new_frame_audio contains anything.
                RefCountedFrame new_frame;
                GLsync new_data_ready_fence;  // Whether new_frame is ready for rendering.
+               std::vector<float> new_frame_audio;
                std::condition_variable new_data_ready_changed;  // Set whenever new_data_ready is changed.
+               Resampler *resampler = nullptr;
        };
        CaptureCard cards[NUM_CARDS];  // protected by <bmusb_mutex>